@@ -1,7 +1,7 @@
 from .base import base
 
 
-class fab(base):
+class articles(base):
     def __init__(self, token):
         super().__init__(token)
 
